@@ -23,8 +23,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O2 -Wall -g '
            ' '
            ' -fstack-protector-strong '
-           '-Wformat -Werror=format-security  -fexceptions  -g -flto '
-           '-fuse-linker-plugin -ffat-lto-objects',
+           '-Wformat -Werror=format-security  -fexceptions  -g -fwrapv -O2 '
+           '  ',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -58,8 +58,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.7m',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python3.7-DDgC_P/python3.7-3.7.3/build-shared/coverage.info',
- 'COVERAGE_REPORT': '/build/python3.7-DDgC_P/python3.7-3.7.3/build-shared/lcov-report',
+ 'COVERAGE_INFO': '/build/python3.7-3DgFBe/python3.7-3.7.5/build-shared/coverage.info',
+ 'COVERAGE_REPORT': '/build/python3.7-3DgFBe/python3.7-3.7.5/build-shared/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. -I../Include -Wdate-time '
@@ -407,7 +407,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_STRINGS_H': 1,
  'HAVE_STRING_H': 1,
  'HAVE_STRLCPY': 0,
- 'HAVE_STROPTS_H': 1,
+ 'HAVE_STROPTS_H': 0,
  'HAVE_STRUCT_PASSWD_PW_GECOS': 1,
  'HAVE_STRUCT_PASSWD_PW_PASSWD': 1,
  'HAVE_STRUCT_STAT_ST_BIRTHTIME': 0,
@@ -643,9 +643,10 @@ build_time_vars = {'ABIFLAGS': 'm',
                              ' '
                              ' '
                              '-fstack-protector-strong -Wformat '
-                             '-Werror=format-security  -fexceptions  -g -flto '
-                             '-fuse-linker-plugin -ffat-lto-objects -std=c99 '
-                             '-Wextra -Wno-unused-result -Wno-unused-parameter '
+                             '-Werror=format-security  -fexceptions  -g '
+                             '-fwrapv -O2   '
+                             ' -std=c99 -Wextra '
+                             '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wno-cast-function-type '
                              '-Werror=implicit-function-declaration -IObjects '
@@ -655,8 +656,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O2 -Wall '
               '-g  '
               ' -fstack-protector-strong '
-              '-Wformat -Werror=format-security  -fexceptions  -g -flto '
-              '-fuse-linker-plugin -ffat-lto-objects',
+              '-Wformat -Werror=format-security  -fexceptions  -g -fwrapv -O2 '
+              '  ',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Wno-cast-function-type '
@@ -667,8 +668,8 @@ build_time_vars = {'ABIFLAGS': 'm',
                    ' '
                    ' '
                    '-fstack-protector-strong -Wformat -Werror=format-security  '
-                   '-fexceptions  -g -flto -fuse-linker-plugin '
-                   '-ffat-lto-objects -std=c99 -Wextra -Wno-unused-result '
+                   '-fexceptions  -g -fwrapv -O2   '
+                   ' -std=c99 -Wextra -Wno-unused-result '
                    '-Wno-unused-parameter -Wno-missing-field-initializers '
                    '-Wno-cast-function-type '
                    '-Werror=implicit-function-declaration -IObjects -IInclude '
@@ -686,9 +687,10 @@ build_time_vars = {'ABIFLAGS': 'm',
                         ' '
                         ' '
                         '-fstack-protector-strong -Wformat -Werror=format-security  '
-                        '-fexceptions  -g -flto -fuse-linker-plugin '
-                        '-ffat-lto-objects -std=c99 -Wextra -Wno-unused-result '
-                        '-Wno-unused-parameter -Wno-missing-field-initializers '
+                        '-fexceptions  -g -fwrapv -O2  '
+                        '  -std=c99 '
+                        '-Wextra -Wno-unused-result -Wno-unused-parameter '
+                        '-Wno-missing-field-initializers '
                         '-Wno-cast-function-type '
                         '-Werror=implicit-function-declaration -IObjects '
                         '-IInclude -IPython -I. -I../Include -Wdate-time '
@@ -700,7 +702,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python3.7-DDgC_P/python3.7-3.7.3/build-shared',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python3.7-3DgFBe/python3.7-3.7.5/build-shared',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '@SGI_ABI@',
@@ -728,7 +730,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-37m-powerpc64le-linux-gnu',
- 'SRCDIRS': 'Parser Objects Python Modules Programs',
+ 'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
  'SRC_GDB_HOOKS': '../Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
@@ -742,10 +744,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python3.7-DDgC_P/python3.7-3.7.3/build-shared '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python3.7-3DgFBe/python3.7-3.7.5/build-shared '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python3.7-DDgC_P/python3.7-3.7.3/build-shared '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python3.7-3DgFBe/python3.7-3.7.5/build-shared '
                './python ../Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -767,8 +769,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python3.7-DDgC_P/python3.7-3.7.3/build-shared',
- 'abs_srcdir': '/build/python3.7-DDgC_P/python3.7-3.7.3/build-shared/..',
+ 'abs_builddir': '/build/python3.7-3DgFBe/python3.7-3.7.5/build-shared',
+ 'abs_srcdir': '/build/python3.7-3DgFBe/python3.7-3.7.5/build-shared/..',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
