@@ -102,9 +102,9 @@ class UpdateGroup(UpdateItem):
             # This shouldn't really happen. If we land here often, it's a sign
             # that something has gone wrong. Unless all pkgs are None it's not
             # a critical issue - a hit to the performance at most.
-            reason = ((not pkg or not pkg.candidate) and
-                      "Package was None or didn't have a candidate." or
-                      "%s already in _deps." % pkg.name)
+            reason = ((not pkg or not pkg.candidate)
+                      and "Package was None or didn't have a candidate."
+                      or "%s already in _deps." % pkg.name)
             logging.debug("Useless call to _add_deps. %s" % reason)
             return
         if len(self._deps) % 200 == 0 and callable(eventloop_callback):
@@ -140,8 +140,8 @@ class UpdateGroup(UpdateItem):
 
     def selection_is_inconsistent(self):
         pkgs_installing = [item for item in self.items if item.is_selected()]
-        return (len(pkgs_installing) > 0 and
-                len(pkgs_installing) < len(self.items))
+        return (len(pkgs_installing) > 0
+                and len(pkgs_installing) < len(self.items))
 
     def get_total_size(self):
         if self.to_remove:
@@ -338,9 +338,9 @@ class UpdateList():
         inst_ver = pkg._pkg.current_ver
         for ver in pkg._pkg.version_list:
             # discard is < than installed ver
-            if (inst_ver and
-                    apt.apt_pkg.version_compare(ver.ver_str,
-                                                inst_ver.ver_str) <= 0):
+            if (inst_ver
+                    and apt.apt_pkg.version_compare(ver.ver_str,
+                                                    inst_ver.ver_str) <= 0):
                 continue
             # check if we have a match
             for (verFileIter, index) in ver.file_list:
@@ -507,14 +507,15 @@ class UpdateList():
                     upgrade_pkgs.append(pkg)
                 self.num_updates = self.num_updates + 1
 
-            if pkg.is_upgradable and not (pkg.marked_upgrade or
-                                          pkg.marked_install):
+            if pkg.is_upgradable and not (pkg.marked_upgrade
+                                          or pkg.marked_install):
                 self.held_back.append(pkg.name)
                 continue
-            if (pkg.is_auto_removable and
-                (cache.versioned_kernel_pkgs_regexp and
-                 cache.versioned_kernel_pkgs_regexp.match(pkg.name) and
-                 not cache.running_kernel_pkgs_regexp.match(pkg.name))):
+            if (pkg.is_auto_removable
+                and (cache.versioned_kernel_pkgs_regexp
+                     and cache.versioned_kernel_pkgs_regexp.match(pkg.name)
+                     and not cache.running_kernel_pkgs_regexp.match(
+                         pkg.name))):
                 kernel_autoremove_pkgs.append(pkg)
 
         # perform operations after the loop to not skip packages which
